==> RTCA_1.4.0.tgz: RTCA/doc/RTCAtransformation.R <==
###################################################
### chunk number 1: lib
###################################################
#line 66 "RTCAtransformation.Rnw"
library(xtable)
library(RTCA)


###################################################
### chunk number 2: dataset
###################################################
#line 72 "RTCAtransformation.Rnw"
ofile <-  system.file("extdata/testOutput.csv", package="RTCA")
pfile <- system.file("extdata/testOutputPhenoData.csv", package="RTCA")
pData <- read.csv(pfile, sep="\t", row.names="Well")
metaData <- data.frame(labelDescription=c(
                         "Rack number",
                         "siRNA catalogue number",
                         "siRNA gene symbol",
                         "siRNA EntrezGene ID",
                         "siRNA targeting accession"
                         ))
phData <- new("AnnotatedDataFrame", data=pData, varMetadata=metaData)
x <- parseRTCA(ofile, phenoData=phData)


###################################################
### chunk number 3: dims
###################################################
#line 87 "RTCAtransformation.Rnw"
xTimePointNo <- dim(x)[[1]]
xSampleNo <- dim(x)[[2]]


###################################################
### chunk number 4: smoothTransform
###################################################
#line 107 "RTCAtransformation.Rnw"
xSmooth <- smoothTransform(x)


###################################################
### chunk number 5: interpolationTranform
###################################################
#line 125 "RTCAtransformation.Rnw"
xInter <- interpolationTransform(x)


###################################################
### chunk number 6: derivTransform
###################################################
#line 140 "RTCAtransformation.Rnw"
xDeriv <- derivativeTransform(x)


###################################################
### chunk number 7: rgrTransform
###################################################
#line 154 "RTCAtransformation.Rnw"
xRgr <- rgrTransform(x)


###################################################
### chunk number 8: sessionInfo
###################################################
#line 160 "RTCAtransformation.Rnw"
toLatex(sessionInfo())

==> RTCA_1.54.0.tgz: RTCA/doc/RTCAtransformation.R <==
### R code from vignette source 'RTCAtransformation.Rnw'

###################################################
### code chunk number 1: lib
###################################################
library(xtable)
library(RTCA)


###################################################
### code chunk number 2: dataset
###################################################
ofile <-  system.file("extdata/testOutput.csv", package="RTCA")
pfile <- system.file("extdata/testOutputPhenoData.csv", package="RTCA")
pData <- read.csv(pfile, sep="\t", row.names="Well")
metaData <- data.frame(labelDescription=c(
                         "Rack number",
                         "siRNA catalogue number",
                         "siRNA gene symbol",
                         "siRNA EntrezGene ID",
                         "siRNA targeting accession"
                         ))
phData <- new("AnnotatedDataFrame", data=pData, varMetadata=metaData)
x <- parseRTCA(ofile, phenoData=phData)


###################################################
### code chunk number 3: dims
###################################################
xTimePointNo <- dim(x)[[1]]
xSampleNo <- dim(x)[[2]]


###################################################
### code chunk number 4: smoothTransform
###################################################
xSmooth <- smoothTransform(x)


###################################################
### code chunk number 5: interpolationTranform
###################################################
xInter <- interpolationTransform(x)


###################################################
### code chunk number 6: derivTransform
###################################################
xDeriv <- derivativeTransform(x)


###################################################
### code chunk number 7: rgrTransform
###################################################
xRgr <- rgrTransform(x)


###################################################
### code chunk number 8: sessionInfo
###################################################
toLatex(sessionInfo())
